
Loge - Easy and fast dynamic report generation with Python
----------------------------------------------------------

Changelog
---------

Loge 0.1.7 - first public release (alpha stage)

Description
-----------

Loge is a tool for crating dynamic reports with Python. Report source is written in python with some additional special syntax where you can define report content and format.

Installation
------------

Minimal Loge requirements:

1. Python 3
2. pyqt5
3. mistune

Optional Loge dependencies (to make all Loge features available):

1. unum
2. matplotlib
3. svgvrite
4. pillow

Loge is available through PyPI and can be install with pip command. To install Loge with minimal requirements use pip by typing ::

    pip install loge

You can install optional dependencies by taping: ::

    pip install unum matplotlib svgvrite pillow


To run Loge use command: ::

    loge

Please find more information about installing process at project website.

License
-------

Copyright (C) 2017, the Loge development team

Loge is distributed under the terms of GNU General Public License

The full license can be found in 'license.txt'

Loge development team can be found in 'development.txt'

About us
--------

The development of Loge is coordinated by Albert Defler and Lukasz Laba. See development.txt file for a complete list of people who helped develop Loge.

Contributions
-------------

If you want to help out, create a pull request or start a discussion in our group forum.

More information
----------------

Project website: https://loge.readthedocs.io

Google group forum: https://groups.google.com/d/forum/python_loge

Code repository: https://bitbucket.org/psv_team/loge

Contact: Lukasz Laba <lukaszlab@o2.pl>, Albert Defler <alde@interia.eu>.